==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/actions/file/ExportASCIIAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.file;

import java.io.File;
import java.io.FileNotFoundException;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.TypedEvent;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.helper.SyncThread;
import org.herac.tuxguitar.gui.util.ConfirmDialog;
import org.herac.tuxguitar.gui.util.FileChooser;
import org.herac.tuxguitar.io.exporter.ASCIITabOutputStream;

/**
 * @author julian
 * 
 * TODO To change the template for this generated type comment go to Window - Preferences - Java - Code Style - Code Templates
 */
public class ExportASCIIAction extends Action {
	public static final String NAME = "EXPORT_ASCII";

	public ExportASCIIAction(TablatureEditor tablatureEditor) {
		super(NAME,tablatureEditor);
	}

	public boolean doAction(TypedEvent e) {
		String defaultFileName = chengeFormat(TuxGuitar.instance().getFileHistory().getFileName(),getDefaultExtension());
		
		Shell parent = getEditor().getTablature().getShell();
		String[] filterNames = null;
		String[] filterExtensions = new String[] { "*.tab" };
		String selectedName = FileChooser.instance().save(parent,FileChooser.EXPORT_ASCII_FORMAT, defaultFileName);
		if (selectedName != null) {
			boolean canWrite = true;
			if (!isSuportedFormat(selectedName)) {
				selectedName += getDefaultExtension();
			}
			final String fileName = selectedName;

			File file = new File(fileName);
			if (file.exists()) {
				ConfirmDialog confirm = new ConfirmDialog(getEditor().getTablature().getShell(), TuxGuitar.getProperty("replace-file-question"));

				if (!confirm.confirm()) {
					canWrite = false;
				}
			}

			if (canWrite) {
				getEditor().getTablature().changeCursor(SWT.CURSOR_WAIT);
				new Thread(new Runnable() {
					public void run() {						
						try {							
							new ASCIITabOutputStream(fileName).writeSong(getSongManager().getSong());							
						} catch (FileNotFoundException e) {
							e.printStackTrace();
						}
						new SyncThread(new Runnable() {
							public void run() {
							    if(!TuxGuitar.isDisposed()){
							    	getEditor().getTablature().changeCursor(SWT.CURSOR_ARROW);
							    }
							}
						}).start();
					}
				}).start();
			}
		}

		return true;
	}	

	private String getDefaultFileName(String fileName) {
		String defaultFileName = "untitled";
		String defaultExtencion = getDefaultExtension();
		if (fileName == null) {
			fileName = defaultFileName + defaultExtencion;
		} else if (!isSuportedFormat(fileName)) {
			fileName = chengeFormat(fileName, defaultExtencion);
		}

		return fileName;
	}

	private boolean isSuportedFormat(String fileName) {
		return (fileName.endsWith(getDefaultExtension()));
	}

	private String chengeFormat(String fileName, String format) {
		return removeExtension(fileName) + format;
	}

	private String removeExtension(String fileName) {
		int index = fileName.lastIndexOf('.');
		return fileName.substring(0, index);
	}

	private String getDefaultExtension() {
		return ".tab";
	}

}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/actions/file/ExportASCIIAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.file;

import java.io.File;
import java.io.FileNotFoundException;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.TypedEvent;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.editors.TablatureEditor;
import org.herac.tuxguitar.gui.helper.SyncThread;
import org.herac.tuxguitar.gui.util.ConfirmDialog;
import org.herac.tuxguitar.gui.util.FileChooser;
import org.herac.tuxguitar.io.exporter.ASCIITabOutputStream;

/**
 * @author julian
 * 
 * TODO To change the template for this generated type comment go to Window - Preferences - Java - Code Style - Code Templates
 */
public class ExportASCIIAction extends Action {
	public static final String NAME = "action.file.export-ascii";

	public ExportASCIIAction(TablatureEditor tablatureEditor) {
		super(NAME,tablatureEditor);
	}

	public boolean doAction(TypedEvent e) {		
		Shell parent = getEditor().getTablature().getShell();
		String selectedName = FileChooser.instance().save(parent,FileChooser.EXPORT_ASCII_FORMAT);
		if (selectedName != null) {
			boolean canWrite = true;
			if (!isSuportedFormat(selectedName)) {
				selectedName += getDefaultExtension();
			}
			final String fileName = selectedName;

			File file = new File(fileName);
			if (file.exists()) {
				ConfirmDialog confirm = new ConfirmDialog(getEditor().getTablature().getShell(), TuxGuitar.getProperty("replace-file-question"));

				if (!confirm.confirm()) {
					canWrite = false;
				}
			}

			if (canWrite) {
				getEditor().getTablature().changeCursor(SWT.CURSOR_WAIT);
				new SyncThread(new Runnable() {
					public void run() {
						if(!TuxGuitar.isDisposed()){
							try {																					
								new ASCIITabOutputStream(fileName).writeSong(getSongManager().getSong());
								getEditor().getTablature().changeCursor(SWT.CURSOR_ARROW);						    									
							} catch (FileNotFoundException e) {
								e.printStackTrace();
							}	
						}
					}
				}).start();
			}
		}

		return true;
	}	

	private boolean isSuportedFormat(String fileName) {
		return (fileName.endsWith(getDefaultExtension()));
	}

	private String getDefaultExtension() {
		return ".tab";
	}

}
